@@ -649,32 +649,10 @@ Interfaces = Literal["camera", "ptz", "prebuffer", "audioDetector", "motionDetec
 
 class CameraDelegate(metaclass=ABCMeta):
     @abstractmethod
-    async def snapshotRequest(self, request_id: str, source_name: str) -> Union[bytes, None]: ...
-
-    @abstractmethod
-    async def startStream(
-        self, request_id: str, source_name: str, video_port: int, audio_port: int
-    ) -> None: ...
-
-    @abstractmethod
-    async def stopStream(self, request_id: str, source_name: str) -> None: ...
-
-    @abstractmethod
-    async def onTalkbackSdp(
-        self, request_id: str, source_name: str, sdp: str, codec: TalkbackCodec
-    ) -> None: ...
-
-    @abstractmethod
-    async def onTalkbackRtp(self, request_id: str, source_name: str, rtp: bytes) -> None: ...
+    async def reboot(self) -> None: ...
 
 
-CameraDelegateMethodNames = Literal[
-    "snapshotRequest",
-    "startStream",
-    "stopStream",
-    "onTalkbackSdp",
-    "onTalkbackRtp",
-]
+CameraDelegateMethodNames = Literal["reboot",]
 
 
 class CameraPrebufferDelegate(metaclass=ABCMeta):
@@ -874,6 +852,8 @@ class CameraDevice(Protocol):
     recording_source: CameraSource
     detection_source: CameraSource
 
+    cameraDelegate: CameraDelegate
+    prebufferDelegate: CameraPrebufferDelegate
     ptzDelegate: CameraPTZDelegate
     audioDetectorDelegate: CameraAudioDetectionDelegate
     motionDetectorDelegate: CameraMotionDetectionDelegate
@@ -920,8 +900,10 @@ class CameraDevice(Protocol):
         BatteryState,
     ]: ...
 
-    async def add_camera_source(self, source: "CameraInputSettings") -> None: ...
-    async def update_camera_source(self, source_id: str, source: "CameraInputSettingsPartial") -> None: ...
+    async def add_camera_source(self, source: "CameraConfigInputSettings") -> None: ...
+    async def update_camera_source(
+        self, source_id: str, source: "CameraConfigInputSettingsPartial"
+    ) -> None: ...
     async def remove_camera_source(self, source_id: str) -> None: ...
 
     @overload
@@ -1022,14 +1004,7 @@ class BaseCameraConfig(TypedDict):
     info: NotRequired[CameraInformation]
 
 
-class CameraInputSettings(TypedDict):
-    # _id: str
-    name: str
-    roles: list[CameraRoles]
-    urls: list[str]
-
-
-class CameraInputSettingsPartial(TypedDict, total=False):
+class CameraConfigInputSettingsPartial(TypedDict, total=False):
     # _id: str
     name: str
     roles: list[CameraRoles]
@@ -1039,7 +1014,7 @@ class CameraInputSettingsPartial(TypedDict, total=False):
 class CameraConfigInputSettings(TypedDict):
     name: str
     roles: list[CameraRoles]
-    urls: NotRequired[list[str]]
+    urls: list[str]
 
 
 class CameraConfig(BaseCameraConfig):
